==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/timeseriesinsights/kotlin/inputs/GetGen1EnvironmentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.timeseriesinsights.kotlin.inputs

import com.pulumi.azurenative.timeseriesinsights.inputs.GetGen1EnvironmentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property environmentName The name of the Time Series Insights environment associated with the specified resource group.
 * @property expand Setting $expand=status will include the status of the internal services of the environment in the Time Series Insights service.
 * @property resourceGroupName Name of an Azure Resource group.
 */
public data class GetGen1EnvironmentPlainArgs(
    public val environmentName: String,
    public val expand: String? = null,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.timeseriesinsights.inputs.GetGen1EnvironmentPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.timeseriesinsights.inputs.GetGen1EnvironmentPlainArgs =
        com.pulumi.azurenative.timeseriesinsights.inputs.GetGen1EnvironmentPlainArgs.builder()
            .environmentName(environmentName.let({ args0 -> args0 }))
            .expand(expand?.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGen1EnvironmentPlainArgs].
 */
@PulumiTagMarker
public class GetGen1EnvironmentPlainArgsBuilder internal constructor() {
    private var environmentName: String? = null

    private var expand: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the Time Series Insights environment associated with the specified resource group.
     */
    @JvmName("whksnqedpvmswndb")
    public suspend fun environmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.environmentName = mapped
    }

    /**
     * @param value Setting $expand=status will include the status of the internal services of the environment in the Time Series Insights service.
     */
    @JvmName("vxllynfqvwsrocwj")
    public suspend fun expand(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.expand = mapped
    }

    /**
     * @param value Name of an Azure Resource group.
     */
    @JvmName("glbrnlhlcjvirrii")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetGen1EnvironmentPlainArgs = GetGen1EnvironmentPlainArgs(
        environmentName = environmentName ?: throw PulumiNullFieldException("environmentName"),
        expand = expand,
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/timeseriesinsights/kotlin/inputs/GetGen1EnvironmentPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.timeseriesinsights.kotlin.inputs

import com.pulumi.azurenative.timeseriesinsights.inputs.GetGen1EnvironmentPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property environmentName The name of the Time Series Insights environment associated with the specified resource group.
 * @property expand Setting $expand=status will include the status of the internal services of the environment in the Time Series Insights service.
 * @property resourceGroupName Name of an Azure Resource group.
 */
public data class GetGen1EnvironmentPlainArgs(
    public val environmentName: String,
    public val expand: String? = null,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.timeseriesinsights.inputs.GetGen1EnvironmentPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.timeseriesinsights.inputs.GetGen1EnvironmentPlainArgs =
        com.pulumi.azurenative.timeseriesinsights.inputs.GetGen1EnvironmentPlainArgs.builder()
            .environmentName(environmentName.let({ args0 -> args0 }))
            .expand(expand?.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGen1EnvironmentPlainArgs].
 */
@PulumiTagMarker
public class GetGen1EnvironmentPlainArgsBuilder internal constructor() {
    private var environmentName: String? = null

    private var expand: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the Time Series Insights environment associated with the specified resource group.
     */
    @JvmName("bektejdcudbymdet")
    public suspend fun environmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.environmentName = mapped
    }

    /**
     * @param value Setting $expand=status will include the status of the internal services of the environment in the Time Series Insights service.
     */
    @JvmName("wutgyqkyqbqevhuw")
    public suspend fun expand(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.expand = mapped
    }

    /**
     * @param value Name of an Azure Resource group.
     */
    @JvmName("hydmfgghkkekiuii")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetGen1EnvironmentPlainArgs = GetGen1EnvironmentPlainArgs(
        environmentName = environmentName ?: throw PulumiNullFieldException("environmentName"),
        expand = expand,
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
